pub trait ICCameraFile: Sized {
// Required methods
unsafe fn fileSize(self) -> off_t;
unsafe fn orientation(self) -> ICEXIFOrientationType;
unsafe fn duration(self) -> c_double;
unsafe fn sidecarFiles(self) -> id;
}Expand description
This class represents a folder on an ICCameraDevice object.
Required Methods
Sourceunsafe fn orientation(self) -> ICEXIFOrientationType
unsafe fn orientation(self) -> ICEXIFOrientationType
Desired orientation of image to use when it is downloaded.
Sourceunsafe fn sidecarFiles(self) -> id
unsafe fn sidecarFiles(self) -> id
This property is NULL if there are no sidecar files associated with this file. Otherwise it is an array of ICCameraFile instances of sidecar files associated with this file. An example of a sidecar file is a file with the same base name as this file and having an extension XMP.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".