ICCameraItem

Trait ICCameraItem 

pub trait ICCameraItem: Sized {
Show 16 methods // Required methods unsafe fn device(self) -> id; unsafe fn parentFolder(self) -> id; unsafe fn name(self) -> id; unsafe fn UTI(self) -> id; unsafe fn fileSystemPath(self) -> id; unsafe fn isLocked(self) -> BOOL; unsafe fn isRaw(self) -> BOOL; unsafe fn isInTemporaryStore(self) -> BOOL; unsafe fn creationDate(self) -> id; unsafe fn modificationDate(self) -> id; unsafe fn thumbnailIfAvailable(self) -> CGImageRef; unsafe fn largeThumbnailIfAvailable(self) -> CGImageRef; unsafe fn metadataIfAvailable(self) -> id; unsafe fn userData(self) -> id; unsafe fn ptpObjectHandle(self) -> c_uint; unsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL;
}
ICCameraItem is an abstract class that represents an item in an ICCameraDevice object

Required Methods

unsafe fn device(self) -> id

Parent device of this folder.

unsafe fn parentFolder(self) -> id

Parent folder of this folder.

unsafe fn name(self) -> id

Name of this folder.

unsafe fn UTI(self) -> id

Item UTI. This is an Uniform Type Identifier string.

unsafe fn fileSystemPath(self) -> id

The file system path of the item for items on a device with transportType of ICTransportTypeMassStorage.

unsafe fn isLocked(self) -> BOOL

Indicates the protection state of this folder.

unsafe fn isRaw(self) -> BOOL

Indicates if the file is a raw image file.

unsafe fn isInTemporaryStore(self) -> BOOL

Indicates if this folder is in a temporary store.

unsafe fn creationDate(self) -> id

Creation date of this file.

unsafe fn modificationDate(self) -> id

Modification date of this file.

unsafe fn thumbnailIfAvailable(self) -> CGImageRef

Thumbnail for the item if one is readily available.

unsafe fn largeThumbnailIfAvailable(self) -> CGImageRef

Large thumbnail for the item if one is readily available.

unsafe fn metadataIfAvailable(self) -> id

Metadata for the file if one is readily available.

unsafe fn userData(self) -> id

A mutable dictionary to store arbitrary key-value pairs associated with a camera item object.

unsafe fn ptpObjectHandle(self) -> c_uint

PTP object handle value if the item is on a camera that uses PTP protocol.

unsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL

This property is set if the file is captured on the device after the device’s content is fully enumerated.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICCameraItem for id

Source

unsafe fn device(self) -> id

Source

unsafe fn parentFolder(self) -> id

Source

unsafe fn name(self) -> id

Source

unsafe fn UTI(self) -> id

Source

unsafe fn fileSystemPath(self) -> id

Source

unsafe fn isLocked(self) -> BOOL

Source

unsafe fn isRaw(self) -> BOOL

Source

unsafe fn isInTemporaryStore(self) -> BOOL

Source

unsafe fn creationDate(self) -> id

Source

unsafe fn modificationDate(self) -> id

Source

unsafe fn thumbnailIfAvailable(self) -> CGImageRef

Source

unsafe fn largeThumbnailIfAvailable(self) -> CGImageRef

Source

unsafe fn metadataIfAvailable(self) -> id

Source

unsafe fn userData(self) -> id

Source

unsafe fn ptpObjectHandle(self) -> c_uint

Source

unsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL

Implementors