ICDevice

Trait ICDevice 

pub trait ICDevice: Sized {
Show 28 methods // Required methods unsafe fn delegate(self) -> id; unsafe fn setDelegate(self, delegate: id); unsafe fn type_(self) -> ICDeviceType; unsafe fn name(self) -> id; unsafe fn icon(self) -> CGImageRef; unsafe fn capabilities(self) -> id; unsafe fn modulePath(self) -> id; unsafe fn moduleVersion(self) -> id; unsafe fn isRemote(self) -> BOOL; unsafe fn transportType(self) -> id; unsafe fn usbLocationID(self) -> c_int; unsafe fn usbProductID(self) -> c_int; unsafe fn usbVendorID(self) -> c_int; unsafe fn fwGUID(self) -> c_longlong; unsafe fn serialNumberString(self) -> id; unsafe fn locationDescription(self) -> id; unsafe fn hasOpenSession(self) -> BOOL; unsafe fn UUIDString(self) -> id; unsafe fn persistentIDString(self) -> id; unsafe fn buttonPressed(self) -> id; unsafe fn autolaunchApplicationPath(self) -> id; unsafe fn setAutolaunchApplicationPath(self, autolaunchApplicationPath: id); unsafe fn userData(self) -> id; unsafe fn requestOpenSession(self); unsafe fn requestCloseSession(self); unsafe fn requestYield(self); unsafe fn requestSendMessage( self, messageCode: u64, outData: id, maxReturnedDataSize: u64, sendMessageDelegate: id, didSendMessageSelector: id, contextInfo: id, ); unsafe fn requestEjectOrDisconnect(self);
}

Required Methods

unsafe fn delegate(self) -> id

Get the delegate.

unsafe fn setDelegate(self, delegate: id)

Set the delegate.

unsafe fn type_(self) -> ICDeviceType

The type of the device as defined by ICDeviceType OR’d with its ICDeviceLocationType. The type of this device can be obtained by AND’ing the value retuned by this property with an appropriate ICDeviceTypeMask. The location type of this device can be obtained by AND’ing the value retuned by this property with an appropriate ICDeviceLocationTypeMask.

unsafe fn name(self) -> id

Name of the device as reported by the device module or by the device transport when a device module is not in control of this device. This name may change if the device module overrides the default name of the device reported by the device’s transport, or if the name of the filesystem volume mounted by the device is changed by the user.

unsafe fn icon(self) -> CGImageRef

Icon image for the device.

unsafe fn capabilities(self) -> id

The capabilities of the device as reported by the device module.

unsafe fn modulePath(self) -> id

Filesystem path of the device module that is associated with this device.

unsafe fn moduleVersion(self) -> id

The bundle version of the device module associated with this device.

unsafe fn isRemote(self) -> BOOL

Indicates whether the device is a remote device published by Image Capture device sharing facility.

unsafe fn transportType(self) -> id

The transport type used by the device.

unsafe fn usbLocationID(self) -> c_int

The USB location ID of a USB device in the IOKit registry. This will be 0 for non-USB devices.

unsafe fn usbProductID(self) -> c_int

The USB product ID of a USB device in the IOKit registry. This will be 0 for non-USB devices.

unsafe fn usbVendorID(self) -> c_int

The USB vendor ID of a USB device in the IOKit registry. This will be 0 for non-USB devices.

unsafe fn fwGUID(self) -> c_longlong

The FireWire GUID of a FireWire device in the IOKit registry. This will be 0 for non-FireWire devices.

unsafe fn serialNumberString(self) -> id

The serial number of the device. This will be NULL if the device does not provide a serial number.

unsafe fn locationDescription(self) -> id

A non-localized location description string for the device.

unsafe fn hasOpenSession(self) -> BOOL

Indicates whether the device has an open session.

unsafe fn UUIDString(self) -> id

A string representation of the Universally Unique ID of the device.

unsafe fn persistentIDString(self) -> id

A string representation of the persistent ID of the device.

unsafe fn buttonPressed(self) -> id

A string object with one of the ICButtonType values.

unsafe fn autolaunchApplicationPath(self) -> id

Filesystem path of an application that is to be automatically launched when this device is added.

unsafe fn setAutolaunchApplicationPath(self, autolaunchApplicationPath: id)

Set the filesystem path of an application that is to be automatically launched when this device is added.

unsafe fn userData(self) -> id

A mutable dictionary to store arbitrary key-value pairs associated with a device object. This can be used by view objects that bind to this object to store “house-keeping” information.

unsafe fn requestOpenSession(self)

This message requests to open a session on the device.

unsafe fn requestCloseSession(self)

This message requests to close a previously opened session on this device.

unsafe fn requestYield(self)

This message requests the device module in control of this device to yield control.

unsafe fn requestSendMessage( self, messageCode: u64, outData: id, maxReturnedDataSize: u64, sendMessageDelegate: id, didSendMessageSelector: id, contextInfo: id, )

This method asynchronously sends an arbitrary message with optional data to a device.

unsafe fn requestEjectOrDisconnect(self)

Eject the media if permitted by the device, or disconnect from a remote device.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICDevice for id

Source

unsafe fn delegate(self) -> id

Source

unsafe fn setDelegate(self, delegate: id)

Source

unsafe fn type_(self) -> ICDeviceType

Source

unsafe fn name(self) -> id

Source

unsafe fn icon(self) -> CGImageRef

Source

unsafe fn capabilities(self) -> id

Source

unsafe fn modulePath(self) -> id

Source

unsafe fn moduleVersion(self) -> id

Source

unsafe fn isRemote(self) -> BOOL

Source

unsafe fn transportType(self) -> id

Source

unsafe fn usbLocationID(self) -> c_int

Source

unsafe fn usbProductID(self) -> c_int

Source

unsafe fn usbVendorID(self) -> c_int

Source

unsafe fn fwGUID(self) -> c_longlong

Source

unsafe fn serialNumberString(self) -> id

Source

unsafe fn locationDescription(self) -> id

Source

unsafe fn hasOpenSession(self) -> BOOL

Source

unsafe fn UUIDString(self) -> id

Source

unsafe fn persistentIDString(self) -> id

Source

unsafe fn buttonPressed(self) -> id

Source

unsafe fn autolaunchApplicationPath(self) -> id

Source

unsafe fn setAutolaunchApplicationPath(self, autolaunchApplicationPath: id)

Source

unsafe fn userData(self) -> id

Source

unsafe fn requestOpenSession(self)

Source

unsafe fn requestCloseSession(self)

Source

unsafe fn requestYield(self)

Source

unsafe fn requestSendMessage( self, messageCode: u64, outData: id, maxReturnedDataSize: u64, sendMessageDelegate: id, didSendMessageSelector: id, contextInfo: id, )

Source

unsafe fn requestEjectOrDisconnect(self)

Implementors