ICScannerDevice

Trait ICScannerDevice 

pub trait ICScannerDevice: Sized {
Show 19 methods // Required methods unsafe fn availableFunctionalUnitTypes(self) -> id; unsafe fn selectedFunctionalUnit(self) -> id; unsafe fn transferMode(self) -> ICScannerTransferMode; unsafe fn setTransferMode(self, transferMode: ICScannerTransferMode); unsafe fn maxMemoryBandSize(self) -> u32; unsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32); unsafe fn downloadsDirectory(self) -> id; unsafe fn setDownloadsDirectory(self, downloadsDirectory: id); unsafe fn documentName(self) -> id; unsafe fn setDocumentName(self, documentName: id); unsafe fn documentUTI(self) -> id; unsafe fn setDocumentUTI(self, documentUTI: id); unsafe fn defaultUsername(self) -> id; unsafe fn setDefaultUsername(self, defaultUsername: id); unsafe fn requestOpenSessionWithCredentials( self, username: id, password: id, ); unsafe fn requestSelectFunctionalUnit(self, type_: id); unsafe fn requestOverviewScan(self); unsafe fn requestScan(self); unsafe fn cancelScan(self);
}

Required Methods

unsafe fn availableFunctionalUnitTypes(self) -> id

An array of functional unit types available on this scanner device. This is an array of NSNumber objects whose values are of type ICScannerFunctionalUnitType.

unsafe fn selectedFunctionalUnit(self) -> id

The currently selected functional unit on the scanner device.

unsafe fn transferMode(self) -> ICScannerTransferMode

The transfer mode for scanned document.

unsafe fn setTransferMode(self, transferMode: ICScannerTransferMode)

Set the transfer mode for scanned document.

unsafe fn maxMemoryBandSize(self) -> u32

The total maximum band size requested when performing a ICScannerTransferModeMemoryBased.

unsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32)

Set the total maximum band size requested when performing a ICScannerTransferModeMemoryBased.

unsafe fn downloadsDirectory(self) -> id

The downloads directory.

unsafe fn setDownloadsDirectory(self, downloadsDirectory: id)

Set the downloads directory.

unsafe fn documentName(self) -> id

The document name.

unsafe fn setDocumentName(self, documentName: id)

Set the document name.

unsafe fn documentUTI(self) -> id

The document UTI. Currently supported UTIs are: kUTTypeJPEG, kUTTypeJPEG2000, kUTTypeTIFF, kUTTypePNG etc.

unsafe fn setDocumentUTI(self, documentUTI: id)

Set the document UTI.

unsafe fn defaultUsername(self) -> id

If the device is protected, instead of prompting the user for a username, this property can be set to default to a specific username as a convience. The value will persist until reset by setting it to nil.

unsafe fn setDefaultUsername(self, defaultUsername: id)

Set the default username

unsafe fn requestOpenSessionWithCredentials(self, username: id, password: id)

This message requests to open a session on the protected device with the authorized username and passcode. If the device reports back a failure of credentials, they can be provided here for the launch. A client MUST open a session on a device in order to use the device.

unsafe fn requestSelectFunctionalUnit(self, type_: id)

Requests the scanner device to select a functional unit.

unsafe fn requestOverviewScan(self)

Starts an overview scan on selectedFunctionalUnit.

unsafe fn requestScan(self)

Starts a scan on selectedFunctionalUnit.

unsafe fn cancelScan(self)

cancelScan

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerDevice for id

Source

unsafe fn availableFunctionalUnitTypes(self) -> id

Source

unsafe fn selectedFunctionalUnit(self) -> id

Source

unsafe fn transferMode(self) -> ICScannerTransferMode

Source

unsafe fn setTransferMode(self, transferMode: ICScannerTransferMode)

Source

unsafe fn maxMemoryBandSize(self) -> u32

Source

unsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32)

Source

unsafe fn downloadsDirectory(self) -> id

Source

unsafe fn setDownloadsDirectory(self, downloadsDirectory: id)

Source

unsafe fn documentName(self) -> id

Source

unsafe fn setDocumentName(self, documentName: id)

Source

unsafe fn documentUTI(self) -> id

Source

unsafe fn setDocumentUTI(self, documentUTI: id)

Source

unsafe fn defaultUsername(self) -> id

Source

unsafe fn setDefaultUsername(self, defaultUsername: id)

Source

unsafe fn requestOpenSessionWithCredentials(self, username: id, password: id)

Source

unsafe fn requestSelectFunctionalUnit(self, type_: id)

Source

unsafe fn requestOverviewScan(self)

Source

unsafe fn requestScan(self)

Source

unsafe fn cancelScan(self)

Implementors