ICScannerFeatureBoolean

Trait ICScannerFeatureBoolean 

pub trait ICScannerFeatureBoolean: Sized {
    // Required methods
    unsafe fn value(self) -> BOOL;
    unsafe fn setValue(self, value: BOOL);
}
ICScannerFeatureBoolean object is used to represent a property of a scanner functional unit whose value can be YES or NO.

Required Methods

unsafe fn value(self) -> BOOL

The value of this feature.

unsafe fn setValue(self, value: BOOL)

Set the value of this feature.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFeatureBoolean for id

Source

unsafe fn value(self) -> BOOL

Source

unsafe fn setValue(self, value: BOOL)

Implementors