ICScannerFeatureEnumeration

Trait ICScannerFeatureEnumeration 

pub trait ICScannerFeatureEnumeration: Sized {
    // Required methods
    unsafe fn currentValue(self) -> id;
    unsafe fn setCurrentValue(self, currentValue: id);
    unsafe fn defaultValue(self) -> id;
    unsafe fn values(self) -> id;
    unsafe fn menuItemLabels(self) -> id;
    unsafe fn menuItemLabelsTooltips(self) -> id;
}
ICScannerFeature class is an abstract base class used to describe a scanner feature.

Required Methods

unsafe fn currentValue(self) -> id

The current value. The current value can be set to one of the possible values in the “values” property below.

unsafe fn setCurrentValue(self, currentValue: id)

Set the current value

unsafe fn defaultValue(self) -> id

The default value. The default value can be set to one of the possible values in the “values” property below.

unsafe fn values(self) -> id

An array of possible values. All items in this array must be of same type.

unsafe fn menuItemLabels(self) -> id

The human readable menu item labels to be used in a menu to allow the user to select the current value from an array of possible values.

unsafe fn menuItemLabelsTooltips(self) -> id

Tooltip text associated with the menu items.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFeatureEnumeration for id

Source

unsafe fn currentValue(self) -> id

Source

unsafe fn setCurrentValue(self, currentValue: id)

Source

unsafe fn defaultValue(self) -> id

Source

unsafe fn values(self) -> id

Source

unsafe fn menuItemLabels(self) -> id

Source

unsafe fn menuItemLabelsTooltips(self) -> id

Implementors