ICScannerFeatureRange

Trait ICScannerFeatureRange 

pub trait ICScannerFeatureRange: Sized {
    // Required methods
    unsafe fn currentValue(self) -> CGFloat;
    unsafe fn setCurrentValue(self, currentValue: CGFloat);
    unsafe fn defaultValue(self) -> CGFloat;
    unsafe fn minValue(self) -> CGFloat;
    unsafe fn maxValue(self) -> CGFloat;
    unsafe fn stepSize(self) -> CGFloat;
}
ICScannerFeatureRange object is used to represent a property of a scanner functional unit whose value lies within a range.

Required Methods

unsafe fn currentValue(self) -> CGFloat

The current value. Attempting to set the current value to a value that is not coincident with a step will result in a value corresponding to the nearest step being assigned to the current value.

unsafe fn setCurrentValue(self, currentValue: CGFloat)

Set the current value

unsafe fn defaultValue(self) -> CGFloat

The default value. Attempting to set the default value to a value that is not coincident with a step will result in a value corresponding to the nearest step being assigned to the default value.

unsafe fn minValue(self) -> CGFloat

The minimum value.

unsafe fn maxValue(self) -> CGFloat

The maximum value.

unsafe fn stepSize(self) -> CGFloat

The step size.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFeatureRange for id

Source

unsafe fn currentValue(self) -> CGFloat

Source

unsafe fn setCurrentValue(self, currentValue: CGFloat)

Source

unsafe fn defaultValue(self) -> CGFloat

Source

unsafe fn minValue(self) -> CGFloat

Source

unsafe fn maxValue(self) -> CGFloat

Source

unsafe fn stepSize(self) -> CGFloat

Implementors