ICScannerFeatureTemplate

Trait ICScannerFeatureTemplate 

pub trait ICScannerFeatureTemplate: Sized {
    // Required method
    unsafe fn targets(self) -> id;
}
ICScannerFeatureTemplate object is used to define a group of one or more rectangular scan areas that can be used with a scanner functional unit.

Required Methods

unsafe fn targets(self) -> id

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFeatureTemplate for id

Source

unsafe fn targets(self) -> id

Implementors