ICScannerFunctionalUnit

Trait ICScannerFunctionalUnit 

pub trait ICScannerFunctionalUnit: Sized {
Show 40 methods // Required methods unsafe fn type_(self) -> ICScannerFunctionalUnitType; unsafe fn pixelDataType(self) -> ICScannerPixelDataType; unsafe fn setPixelDataType(self, pixelDataType: ICScannerPixelDataType); unsafe fn supportedBitDepths(self) -> id; unsafe fn bitDepth(self) -> ICScannerBitDepth; unsafe fn setBitDepth(self, bitDepth: ICScannerBitDepth); unsafe fn supportedMeasurementUnits(self) -> id; unsafe fn measurementUnit(self) -> ICScannerMeasurementUnit; unsafe fn setMeasurementUnit( self, measurementUnit: ICScannerMeasurementUnit, ); unsafe fn supportedResolutions(self) -> id; unsafe fn preferredResolutions(self) -> id; unsafe fn resolution(self) -> NSUInteger; unsafe fn setResolution(self, resolution: NSUInteger); unsafe fn nativeXResolution(self) -> NSUInteger; unsafe fn nativeYResolution(self) -> NSUInteger; unsafe fn supportedScaleFactors(self) -> id; unsafe fn preferredScaleFactors(self) -> id; unsafe fn scaleFactor(self) -> NSUInteger; unsafe fn setScaleFactor(self, scaleFactor: NSUInteger); unsafe fn templates(self) -> id; unsafe fn vendorFeatures(self) -> id; unsafe fn physicalSize(self) -> NSSize; unsafe fn scanArea(self) -> NSRect; unsafe fn setScanArea(self, scanArea: NSRect); unsafe fn scanAreaOrientation(self) -> ICEXIFOrientationType; unsafe fn setScanAreaOrientation( self, scanAreaOrientation: ICEXIFOrientationType, ); unsafe fn acceptsThresholdForBlackAndWhiteScanning(self) -> BOOL; unsafe fn usesThresholdForBlackAndWhiteScanning(self) -> BOOL; unsafe fn setUsesThresholdForBlackAndWhiteScanning( self, usesThresholdForBlackAndWhiteScanning: BOOL, ); unsafe fn defaultThresholdForBlackAndWhiteScanning(self) -> c_uchar; unsafe fn thresholdForBlackAndWhiteScanning(self) -> c_uchar; unsafe fn setThresholdForBlackAndWhiteScanning( self, thresholdForBlackAndWhiteScanning: c_uchar, ); unsafe fn state(self) -> ICScannerFunctionalUnitState; unsafe fn scanInProgress(self) -> BOOL; unsafe fn scanProgressPercentDone(self) -> CGFloat; unsafe fn canPerformOverviewScan(self) -> BOOL; unsafe fn overviewScanInProgress(self) -> BOOL; unsafe fn overviewImage(self) -> CGImageRef; unsafe fn overviewResolution(self) -> NSUInteger; unsafe fn setOverviewResolution(self, overviewResolution: NSUInteger);
}
ICScannerFunctionalUnit is an abstract class that represents a scanner functiona unit. ImageCaptureCore defines three concrete subclasses of ICScannerFunctionalUnit: ICScannerFunctionalUnitFlatbed, ICScannerFunctionalUnitPositiveTransparency, ICScannerFunctionalUnitNegativeTransparency and ICScannerFunctionalUnitDocumentFeeder. ICScannerDevice creates instances of these concrete subclasses.

Required Methods

unsafe fn type_(self) -> ICScannerFunctionalUnitType

Functional unit type.

unsafe fn pixelDataType(self) -> ICScannerPixelDataType

The pixel data type.

unsafe fn setPixelDataType(self, pixelDataType: ICScannerPixelDataType)

Set the pixel data type.

unsafe fn supportedBitDepths(self) -> id

Supported bit depths. The values in this set are valid values defined by ICScannerBitDepth.

unsafe fn bitDepth(self) -> ICScannerBitDepth

The bit depth to use when performing the final scan. This will always be one of the supported bit depths.

unsafe fn setBitDepth(self, bitDepth: ICScannerBitDepth)

Set the bit depth to use when performing the final scan.

unsafe fn supportedMeasurementUnits(self) -> id

Supported measurement units. The values in this set are valid values defined by ICScannerMeasurementUnit.

unsafe fn measurementUnit(self) -> ICScannerMeasurementUnit

Current measurement unit. This will always be one of the supported measurement units.

unsafe fn setMeasurementUnit(self, measurementUnit: ICScannerMeasurementUnit)

Set current measurement unit.

unsafe fn supportedResolutions(self) -> id

Supported scan resolutions in DPI.

unsafe fn preferredResolutions(self) -> id

Preferred scan resolutions in DPI.

unsafe fn resolution(self) -> NSUInteger

Current scan resolution. This will always be one of the supported resolution values.

unsafe fn setResolution(self, resolution: NSUInteger)

Set the current scan resolution.

unsafe fn nativeXResolution(self) -> NSUInteger

Optical resolution along the X axis.

unsafe fn nativeYResolution(self) -> NSUInteger

Optical resolution along the Y axis.

unsafe fn supportedScaleFactors(self) -> id

Supported scale factors in percentage.

unsafe fn preferredScaleFactors(self) -> id

Preferred scale factors in percentage.

unsafe fn scaleFactor(self) -> NSUInteger

Current scale factor. This will always be one of the supported scale factor values.

unsafe fn setScaleFactor(self, scaleFactor: NSUInteger)

Set the current scale factor.

unsafe fn templates(self) -> id

An array of objects of type ICScannerFeatureTemplate.

unsafe fn vendorFeatures(self) -> id

An array of objects of type ICScannerFeature.

unsafe fn physicalSize(self) -> NSSize

Physical size of the scan area in current measurement unit.

unsafe fn scanArea(self) -> NSRect

This property along with scanAreaOrientation describes the area to be scanned.

unsafe fn setScanArea(self, scanArea: NSRect)

Set the area to be scanned.

unsafe fn scanAreaOrientation(self) -> ICEXIFOrientationType

Desired orientation of the scan area. This property along with scanArea describes the area to be scanned.

unsafe fn setScanAreaOrientation( self, scanAreaOrientation: ICEXIFOrientationType, )

Set the orientation of the scan area.

unsafe fn acceptsThresholdForBlackAndWhiteScanning(self) -> BOOL

Indicates if this functional unit accepts threshold value to be used when performing a scan in black & white.

unsafe fn usesThresholdForBlackAndWhiteScanning(self) -> BOOL

Indicates if this functional unit uses threshold value to be used when performing a scan in black & white.

unsafe fn setUsesThresholdForBlackAndWhiteScanning( self, usesThresholdForBlackAndWhiteScanning: BOOL, )

Indicate if this functional unit uses threshold value to be used when performing a scan in black & white.

unsafe fn defaultThresholdForBlackAndWhiteScanning(self) -> c_uchar

Default threshold value used when performing a scan in black & white. This value is from 0 to 255.

unsafe fn thresholdForBlackAndWhiteScanning(self) -> c_uchar

Threshold value to be used when performing a scan in black & white. This value should be from 0 to 255.

unsafe fn setThresholdForBlackAndWhiteScanning( self, thresholdForBlackAndWhiteScanning: c_uchar, )

Set the threshold value to be used when performing a scan in black & white.

unsafe fn state(self) -> ICScannerFunctionalUnitState

Indicates the current state of the functional unit.

unsafe fn scanInProgress(self) -> BOOL

Indicates if a scan is in progress.

unsafe fn scanProgressPercentDone(self) -> CGFloat

Indicates percentage of scan completed.

unsafe fn canPerformOverviewScan(self) -> BOOL

Indicates if this functional unit can perfrom an overview scan. Not all functional units can perform an overview scan. For example, a document feeder or a sheet feeder unit cannot perform an overview scan.

unsafe fn overviewScanInProgress(self) -> BOOL

Indicates if an overview scan is in progress.

unsafe fn overviewImage(self) -> CGImageRef

Overview scan image. This property will be NULL for functional units that do not support overview scans.

unsafe fn overviewResolution(self) -> NSUInteger

Overview image resolution. Value assigned to this will be contrained by resolutions allowed by the device.

unsafe fn setOverviewResolution(self, overviewResolution: NSUInteger)

Set the overview image resolution.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFunctionalUnit for id

Source

unsafe fn type_(self) -> ICScannerFunctionalUnitType

Source

unsafe fn pixelDataType(self) -> ICScannerPixelDataType

Source

unsafe fn setPixelDataType(self, pixelDataType: ICScannerPixelDataType)

Source

unsafe fn supportedBitDepths(self) -> id

Source

unsafe fn bitDepth(self) -> ICScannerBitDepth

Source

unsafe fn setBitDepth(self, bitDepth: ICScannerBitDepth)

Source

unsafe fn supportedMeasurementUnits(self) -> id

Source

unsafe fn measurementUnit(self) -> ICScannerMeasurementUnit

Source

unsafe fn setMeasurementUnit(self, measurementUnit: ICScannerMeasurementUnit)

Source

unsafe fn supportedResolutions(self) -> id

Source

unsafe fn preferredResolutions(self) -> id

Source

unsafe fn resolution(self) -> NSUInteger

Source

unsafe fn setResolution(self, resolution: NSUInteger)

Source

unsafe fn nativeXResolution(self) -> NSUInteger

Source

unsafe fn nativeYResolution(self) -> NSUInteger

Source

unsafe fn supportedScaleFactors(self) -> id

Source

unsafe fn preferredScaleFactors(self) -> id

Source

unsafe fn scaleFactor(self) -> NSUInteger

Source

unsafe fn setScaleFactor(self, scaleFactor: NSUInteger)

Source

unsafe fn templates(self) -> id

Source

unsafe fn vendorFeatures(self) -> id

Source

unsafe fn physicalSize(self) -> NSSize

Source

unsafe fn scanArea(self) -> NSRect

Source

unsafe fn setScanArea(self, scanArea: NSRect)

Source

unsafe fn scanAreaOrientation(self) -> ICEXIFOrientationType

Source

unsafe fn setScanAreaOrientation( self, scanAreaOrientation: ICEXIFOrientationType, )

Source

unsafe fn acceptsThresholdForBlackAndWhiteScanning(self) -> BOOL

Source

unsafe fn usesThresholdForBlackAndWhiteScanning(self) -> BOOL

Source

unsafe fn setUsesThresholdForBlackAndWhiteScanning( self, usesThresholdForBlackAndWhiteScanning: BOOL, )

Source

unsafe fn defaultThresholdForBlackAndWhiteScanning(self) -> c_uchar

Source

unsafe fn thresholdForBlackAndWhiteScanning(self) -> c_uchar

Source

unsafe fn setThresholdForBlackAndWhiteScanning( self, thresholdForBlackAndWhiteScanning: c_uchar, )

Source

unsafe fn state(self) -> ICScannerFunctionalUnitState

Source

unsafe fn scanInProgress(self) -> BOOL

Source

unsafe fn scanProgressPercentDone(self) -> CGFloat

Source

unsafe fn canPerformOverviewScan(self) -> BOOL

Source

unsafe fn overviewScanInProgress(self) -> BOOL

Source

unsafe fn overviewImage(self) -> CGImageRef

Source

unsafe fn overviewResolution(self) -> NSUInteger

Source

unsafe fn setOverviewResolution(self, overviewResolution: NSUInteger)

Implementors