ICScannerFunctionalUnitNegativeTransparency

Trait ICScannerFunctionalUnitNegativeTransparency 

pub trait ICScannerFunctionalUnitNegativeTransparency: Sized {
    // Required methods
    unsafe fn supportedDocumentTypes(self) -> id;
    unsafe fn documentType(self) -> ICScannerDocumentType;
    unsafe fn setDocumentType(self, documentType: ICScannerDocumentType);
    unsafe fn documentSize(self) -> NSSize;
}
ICScannerFunctionalUnitNegativeTransparency is a concrete subclass of ICScannerFunctionalUnit class. ICScannerDevice creates instances of this class.

Required Methods

unsafe fn supportedDocumentTypes(self) -> id

Supported document types. The values in this set are valid values defined by ICScannerDocumentType.

unsafe fn documentType(self) -> ICScannerDocumentType

Current document type. This will always be one of the supported document types.

unsafe fn setDocumentType(self, documentType: ICScannerDocumentType)

Set the current document type.

unsafe fn documentSize(self) -> NSSize

Document size of the current document type expressed in current measurement unit.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ICScannerFunctionalUnitNegativeTransparency for id

Implementors