Module camera_device

Module camera_device 

Statics

ICCameraDeviceCanAcceptPTPCommands
Indicates that the camera can accept PTP commands.
ICCameraDeviceCanDeleteAllFiles
Indicates that the camera can delete all files in a single operation while it is connected.
ICCameraDeviceCanDeleteOneFile
Indicates that the camera can delete a file at a time while it is connected.
ICCameraDeviceCanReceiveFile
Indicates that the host can upload files to the camera.
ICCameraDeviceCanSyncClock
Indicates that the camera can synchronize its date and time with that of the host computer.
ICCameraDeviceCanTakePicture
Indicates that the camera can capture a picture while it is connected, if the client sends a ‘requestTakePicture’ message to it.
ICCameraDeviceCanTakePictureUsingShutterReleaseOnCamera
Indicates that the camera can capture a picture while it is connected, if the user presses the shutter release on the camera.
ICDeleteAfterSuccessfulDownload
The value for this key should be an NSNumber object representing a boolean value. If this value is YES, the file will be deleted from the device after it is succcessfully downloaded.
ICDownloadSidecarFiles
The value for this key should be an NSNumber object representing a boolean value. If this value is YES, all sidecar files will be downloaded along with the media file.
ICDownloadsDirectoryURL
The value for this key should be an NSURL object referencing a writable directory. The downloaded files will be saved in that directory.
ICOverwrite
The value for this key should be an NSNumber object representing a boolean value. If this value is YES, the downloaded file will overwrite an existing file with the same name and extension.
ICSaveAsFilename
The value for this key should be an NSString object containing the name to be used for the downloaded file.
ICSavedAncillaryFiles
The value for this key will be an NSArray object containing names of files associated with the primary file that is downloaded. The options dictionary returned in didDownloadFile:error:options:contextInfo: may have this key.
ICSavedFilename
The value for this key will be an NSString object containing the actual name of the saved file. The options dictionary returned in didDownloadFile:error:options:contextInfo: will have this key.
ICTransportTypeUSB
Indicates that the device uses USB transport

Traits

ICCameraDevice