pub trait ICCameraDevice: Sized {
Show 21 methods
// Required methods
unsafe fn batteryLevelAvailable(self) -> BOOL;
unsafe fn batteryLevel(self) -> NSUInteger;
unsafe fn contentCatalogPercentCompleted(self) -> NSUInteger;
unsafe fn contents(self) -> id;
unsafe fn mediaFiles(self) -> id;
unsafe fn timeOffset(self) -> NSTimeInterval;
unsafe fn isAccessRestrictedAppleDevice(self) -> BOOL;
unsafe fn mountPoint(self) -> id;
unsafe fn tetheredCaptureEnabled(self) -> BOOL;
unsafe fn filesOfType(self, fileUTType: id) -> id;
unsafe fn requestSyncClock(self);
unsafe fn requestEnableTethering(self);
unsafe fn requestDisableTethering(self);
unsafe fn requestTakePicture(self);
unsafe fn requestDeleteFiles(self, files: id);
unsafe fn cancelDelete(self);
unsafe fn requestDownloadFile(
self,
file: id,
options: id,
downloadDelegate: id,
didDownloadSelector: id,
contextInfo: id,
);
unsafe fn cancelDownload(self);
unsafe fn requestUploadFile(
self,
fileURL: id,
options: id,
uploadDelegate: id,
didUploadSelector: id,
contextInfo: id,
);
unsafe fn requestReadDataFromFile(
self,
file: id,
atOffset: off_t,
length: off_t,
readDelegate: id,
didReadDataSelector: id,
contextInfo: id,
);
unsafe fn requestSendPTPCommand(
self,
command: id,
outData: id,
sendCommandDelegate: id,
didSendCommandSelector: id,
contextInfo: id,
);
}Required Methods
Sourceunsafe fn batteryLevelAvailable(self) -> BOOL
unsafe fn batteryLevelAvailable(self) -> BOOL
Indicates if the device has reported battery charge level.
Sourceunsafe fn batteryLevel(self) -> NSUInteger
unsafe fn batteryLevel(self) -> NSUInteger
Indicates the battery charge level. Its value ranges from 0 to 100.
Sourceunsafe fn contentCatalogPercentCompleted(self) -> NSUInteger
unsafe fn contentCatalogPercentCompleted(self) -> NSUInteger
Indicates the percentage of content cataloging completed on the device. Its value ranges from 0 to 100.
Sourceunsafe fn contents(self) -> id
unsafe fn contents(self) -> id
Contents of the camera. The structure of the elements in this array will reflect the folder structure of the storage reported by the camera. Each item in this array will correspond to a storage on the camera.
Sourceunsafe fn mediaFiles(self) -> id
unsafe fn mediaFiles(self) -> id
The property mediaFiles represents all image, movie and audio files on the camera. These files are returned as a single array without regard to the folder hierarchy used to store these files on the camera.
Sourceunsafe fn timeOffset(self) -> NSTimeInterval
unsafe fn timeOffset(self) -> NSTimeInterval
Indicates the time offset, in seconds, between the camera’s clock and the computer’s clock. This value is positive if the camera’s clock is ahead of the computer’s clock. This property should be ignored if the camera’s capabilities property does not contain ICCameraDeviceCanSyncClock.
Sourceunsafe fn isAccessRestrictedAppleDevice(self) -> BOOL
unsafe fn isAccessRestrictedAppleDevice(self) -> BOOL
Set to YES if the device is made by Apple and is pass-coded locked and connected to an untrusted host.
Sourceunsafe fn mountPoint(self) -> id
unsafe fn mountPoint(self) -> id
Filesystem mount point for a device with transportType of ICTransportTypeMassStorage. This will be NULL for all other devices.
Sourceunsafe fn tetheredCaptureEnabled(self) -> BOOL
unsafe fn tetheredCaptureEnabled(self) -> BOOL
This property is set to YES when tethered capture is enabled on the device.
Sourceunsafe fn filesOfType(self, fileUTType: id) -> id
unsafe fn filesOfType(self, fileUTType: id) -> id
This method returns an array of files on the camera of type fileType.
Sourceunsafe fn requestSyncClock(self)
unsafe fn requestSyncClock(self)
Synchronize camera’s clock with the computer’s clock. You should send this request only if the camera has the ‘ICCameraDeviceCanSyncClock’ capability.
Sourceunsafe fn requestEnableTethering(self)
unsafe fn requestEnableTethering(self)
Send this message to enable tethered capture on the camera device if the camera has the ‘ICCameraDeviceCanTakePicture’ capability.
Sourceunsafe fn requestDisableTethering(self)
unsafe fn requestDisableTethering(self)
Send this message to disable tethered capture on the camera device if the camera has the ‘ICCameraDeviceCanTakePicture’ capability and if your process has already sent a ‘requestEnableTethering’ to it.
Sourceunsafe fn requestTakePicture(self)
unsafe fn requestTakePicture(self)
Capture a new image using the camera, the camera capabilities include ‘ICCameraDeviceCanTakePicture’.
Sourceunsafe fn requestDeleteFiles(self, files: id)
unsafe fn requestDeleteFiles(self, files: id)
Deletes files.
Sourceunsafe fn cancelDelete(self)
unsafe fn cancelDelete(self)
Cancels the current delete operation started by sending a ‘requestDeleteFiles:’.
Sourceunsafe fn requestDownloadFile(
self,
file: id,
options: id,
downloadDelegate: id,
didDownloadSelector: id,
contextInfo: id,
)
unsafe fn requestDownloadFile( self, file: id, options: id, downloadDelegate: id, didDownloadSelector: id, contextInfo: id, )
Download a file from the camera. Please refer to the top of this header for information about the options.
Sourceunsafe fn cancelDownload(self)
unsafe fn cancelDownload(self)
Cancels the current download operation.
Sourceunsafe fn requestUploadFile(
self,
fileURL: id,
options: id,
uploadDelegate: id,
didUploadSelector: id,
contextInfo: id,
)
unsafe fn requestUploadFile( self, fileURL: id, options: id, uploadDelegate: id, didUploadSelector: id, contextInfo: id, )
Upload a file at fileURL to the camera. The options dictionary is not used in this version.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".