pub trait ICCameraItem: Sized {
Show 16 methods
// Required methods
unsafe fn device(self) -> id;
unsafe fn parentFolder(self) -> id;
unsafe fn name(self) -> id;
unsafe fn UTI(self) -> id;
unsafe fn fileSystemPath(self) -> id;
unsafe fn isLocked(self) -> BOOL;
unsafe fn isRaw(self) -> BOOL;
unsafe fn isInTemporaryStore(self) -> BOOL;
unsafe fn creationDate(self) -> id;
unsafe fn modificationDate(self) -> id;
unsafe fn thumbnailIfAvailable(self) -> CGImageRef;
unsafe fn largeThumbnailIfAvailable(self) -> CGImageRef;
unsafe fn metadataIfAvailable(self) -> id;
unsafe fn userData(self) -> id;
unsafe fn ptpObjectHandle(self) -> c_uint;
unsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL;
}Expand description
ICCameraItem is an abstract class that represents an item in an ICCameraDevice object
Required Methods
Sourceunsafe fn parentFolder(self) -> id
unsafe fn parentFolder(self) -> id
Parent folder of this folder.
Sourceunsafe fn fileSystemPath(self) -> id
unsafe fn fileSystemPath(self) -> id
The file system path of the item for items on a device with transportType of ICTransportTypeMassStorage.
Sourceunsafe fn isInTemporaryStore(self) -> BOOL
unsafe fn isInTemporaryStore(self) -> BOOL
Indicates if this folder is in a temporary store.
Sourceunsafe fn creationDate(self) -> id
unsafe fn creationDate(self) -> id
Creation date of this file.
Sourceunsafe fn modificationDate(self) -> id
unsafe fn modificationDate(self) -> id
Modification date of this file.
Sourceunsafe fn thumbnailIfAvailable(self) -> CGImageRef
unsafe fn thumbnailIfAvailable(self) -> CGImageRef
Thumbnail for the item if one is readily available.
Sourceunsafe fn largeThumbnailIfAvailable(self) -> CGImageRef
unsafe fn largeThumbnailIfAvailable(self) -> CGImageRef
Large thumbnail for the item if one is readily available.
Sourceunsafe fn metadataIfAvailable(self) -> id
unsafe fn metadataIfAvailable(self) -> id
Metadata for the file if one is readily available.
Sourceunsafe fn userData(self) -> id
unsafe fn userData(self) -> id
A mutable dictionary to store arbitrary key-value pairs associated with a camera item object.
Sourceunsafe fn ptpObjectHandle(self) -> c_uint
unsafe fn ptpObjectHandle(self) -> c_uint
PTP object handle value if the item is on a camera that uses PTP protocol.
Sourceunsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL
unsafe fn wasAddedAfterContentCatalogCompleted(self) -> BOOL
This property is set if the file is captured on the device after the device’s content is fully enumerated.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".