pub trait ICScannerDevice: Sized {
Show 19 methods
// Required methods
unsafe fn availableFunctionalUnitTypes(self) -> id;
unsafe fn selectedFunctionalUnit(self) -> id;
unsafe fn transferMode(self) -> ICScannerTransferMode;
unsafe fn setTransferMode(self, transferMode: ICScannerTransferMode);
unsafe fn maxMemoryBandSize(self) -> u32;
unsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32);
unsafe fn downloadsDirectory(self) -> id;
unsafe fn setDownloadsDirectory(self, downloadsDirectory: id);
unsafe fn documentName(self) -> id;
unsafe fn setDocumentName(self, documentName: id);
unsafe fn documentUTI(self) -> id;
unsafe fn setDocumentUTI(self, documentUTI: id);
unsafe fn defaultUsername(self) -> id;
unsafe fn setDefaultUsername(self, defaultUsername: id);
unsafe fn requestOpenSessionWithCredentials(
self,
username: id,
password: id,
);
unsafe fn requestSelectFunctionalUnit(self, type_: id);
unsafe fn requestOverviewScan(self);
unsafe fn requestScan(self);
unsafe fn cancelScan(self);
}Required Methods
Sourceunsafe fn availableFunctionalUnitTypes(self) -> id
unsafe fn availableFunctionalUnitTypes(self) -> id
An array of functional unit types available on this scanner device. This is an array of NSNumber objects whose values are of type ICScannerFunctionalUnitType.
Sourceunsafe fn selectedFunctionalUnit(self) -> id
unsafe fn selectedFunctionalUnit(self) -> id
The currently selected functional unit on the scanner device.
Sourceunsafe fn transferMode(self) -> ICScannerTransferMode
unsafe fn transferMode(self) -> ICScannerTransferMode
The transfer mode for scanned document.
Sourceunsafe fn setTransferMode(self, transferMode: ICScannerTransferMode)
unsafe fn setTransferMode(self, transferMode: ICScannerTransferMode)
Set the transfer mode for scanned document.
Sourceunsafe fn maxMemoryBandSize(self) -> u32
unsafe fn maxMemoryBandSize(self) -> u32
The total maximum band size requested when performing a ICScannerTransferModeMemoryBased.
Sourceunsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32)
unsafe fn setMaxMemoryBandSize(self, maxMemoryBandSize: u32)
Set the total maximum band size requested when performing a ICScannerTransferModeMemoryBased.
Sourceunsafe fn downloadsDirectory(self) -> id
unsafe fn downloadsDirectory(self) -> id
The downloads directory.
Sourceunsafe fn setDownloadsDirectory(self, downloadsDirectory: id)
unsafe fn setDownloadsDirectory(self, downloadsDirectory: id)
Set the downloads directory.
Sourceunsafe fn documentName(self) -> id
unsafe fn documentName(self) -> id
The document name.
Sourceunsafe fn setDocumentName(self, documentName: id)
unsafe fn setDocumentName(self, documentName: id)
Set the document name.
Sourceunsafe fn documentUTI(self) -> id
unsafe fn documentUTI(self) -> id
The document UTI. Currently supported UTIs are: kUTTypeJPEG, kUTTypeJPEG2000, kUTTypeTIFF, kUTTypePNG etc.
Sourceunsafe fn setDocumentUTI(self, documentUTI: id)
unsafe fn setDocumentUTI(self, documentUTI: id)
Set the document UTI.
Sourceunsafe fn defaultUsername(self) -> id
unsafe fn defaultUsername(self) -> id
If the device is protected, instead of prompting the user for a username, this property can be set to default to a specific username as a convience. The value will persist until reset by setting it to nil.
Sourceunsafe fn setDefaultUsername(self, defaultUsername: id)
unsafe fn setDefaultUsername(self, defaultUsername: id)
Set the default username
Sourceunsafe fn requestOpenSessionWithCredentials(self, username: id, password: id)
unsafe fn requestOpenSessionWithCredentials(self, username: id, password: id)
This message requests to open a session on the protected device with the authorized username and passcode. If the device reports back a failure of credentials, they can be provided here for the launch. A client MUST open a session on a device in order to use the device.
Sourceunsafe fn requestSelectFunctionalUnit(self, type_: id)
unsafe fn requestSelectFunctionalUnit(self, type_: id)
Requests the scanner device to select a functional unit.
Sourceunsafe fn requestOverviewScan(self)
unsafe fn requestOverviewScan(self)
Starts an overview scan on selectedFunctionalUnit.
Sourceunsafe fn requestScan(self)
unsafe fn requestScan(self)
Starts a scan on selectedFunctionalUnit.
Sourceunsafe fn cancelScan(self)
unsafe fn cancelScan(self)
cancelScan
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".