pub trait ICScannerFeatureBoolean: Sized {
// Required methods
unsafe fn value(self) -> BOOL;
unsafe fn setValue(self, value: BOOL);
}Expand description
ICScannerFeatureBoolean object is used to represent a property of a scanner functional unit whose value can be YES or NO.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".