pub trait ICScannerFeatureRange: Sized {
// Required methods
unsafe fn currentValue(self) -> CGFloat;
unsafe fn setCurrentValue(self, currentValue: CGFloat);
unsafe fn defaultValue(self) -> CGFloat;
unsafe fn minValue(self) -> CGFloat;
unsafe fn maxValue(self) -> CGFloat;
unsafe fn stepSize(self) -> CGFloat;
}Expand description
ICScannerFeatureRange object is used to represent a property of a scanner functional unit whose value lies within a range.
Required Methods
Sourceunsafe fn currentValue(self) -> CGFloat
unsafe fn currentValue(self) -> CGFloat
The current value. Attempting to set the current value to a value that is not coincident with a step will result in a value corresponding to the nearest step being assigned to the current value.
Sourceunsafe fn setCurrentValue(self, currentValue: CGFloat)
unsafe fn setCurrentValue(self, currentValue: CGFloat)
Set the current value
Sourceunsafe fn defaultValue(self) -> CGFloat
unsafe fn defaultValue(self) -> CGFloat
The default value. Attempting to set the default value to a value that is not coincident with a step will result in a value corresponding to the nearest step being assigned to the default value.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".