pub trait ICScannerFeatureTemplate: Sized {
// Required method
unsafe fn targets(self) -> id;
}Expand description
ICScannerFeatureTemplate object is used to define a group of one or more rectangular scan areas that can be used with a scanner functional unit.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".