pub trait ICScannerFunctionalUnitNegativeTransparency: Sized {
// Required methods
unsafe fn supportedDocumentTypes(self) -> id;
unsafe fn documentType(self) -> ICScannerDocumentType;
unsafe fn setDocumentType(self, documentType: ICScannerDocumentType);
unsafe fn documentSize(self) -> NSSize;
}Expand description
ICScannerFunctionalUnitNegativeTransparency is a concrete subclass of ICScannerFunctionalUnit class. ICScannerDevice creates instances of this class.
Required Methods
Sourceunsafe fn supportedDocumentTypes(self) -> id
unsafe fn supportedDocumentTypes(self) -> id
Supported document types. The values in this set are valid values defined by ICScannerDocumentType.
Sourceunsafe fn documentType(self) -> ICScannerDocumentType
unsafe fn documentType(self) -> ICScannerDocumentType
Current document type. This will always be one of the supported document types.
Sourceunsafe fn setDocumentType(self, documentType: ICScannerDocumentType)
unsafe fn setDocumentType(self, documentType: ICScannerDocumentType)
Set the current document type.
Sourceunsafe fn documentSize(self) -> NSSize
unsafe fn documentSize(self) -> NSSize
Document size of the current document type expressed in current measurement unit.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".